@@ -18,7 +18,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-favicon-cache.c 8146 2008-03-28 15:07:10Z chpe $
  */
 
 #include "config.h"
@@ -31,13 +30,12 @@
 
 #include "ephy-embed-shell.h"
 #include "ephy-embed-persist.h"
-#include "ephy-embed-factory.h"
 #include "ephy-file-helpers.h"
 #include "ephy-node-common.h"
 #include "ephy-node.h"
 #include "ephy-debug.h"
-#include "ephy-glib-compat.h"
 
+#include <glib.h>
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 
@@ -225,6 +223,7 @@ remove_obsolete_icons (EphyFaviconCache *cache,
 
 			g_free (path);
 			ephy_node_unref (kid);
+			priv->dirty = TRUE;
 		}
 	}
 }
@@ -509,7 +508,7 @@ ephy_favicon_cache_download (EphyFaviconCache *cache,
 	dest = g_build_filename (cache->priv->directory, filename, NULL);
 
 	persist = EPHY_EMBED_PERSIST
-		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
+		(g_object_new (EPHY_TYPE_EMBED_PERSIST, NULL));
 
 	ephy_embed_persist_set_dest (persist, dest);
 	ephy_embed_persist_set_flags (persist, EPHY_EMBED_PERSIST_NO_VIEW |
@@ -696,6 +695,7 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 			return NULL;
 		}
 		valid = strcmp (mime_type, "image/x-ico") == 0 ||
+			strcmp (mime_type, "image/vnd.microsoft.icon") == 0 ||
 			strcmp (mime_type, "image/png") == 0 ||
 			strcmp (mime_type, "image/gif") == 0;
 		is_ao = strcmp (mime_type, "application/octet-stream") == 0;
