@@ -1,6 +1,6 @@
 /*
  *  Copyright © 2000-2002 Marco Pesenti Gritti
- *  Copyright © 2006 Christian Persch
+ *  Copyright © 2006, 2008 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
@@ -33,7 +32,9 @@
 #include "ephy-session.h"
 #include "ephy-shell.h"
 #include "ephy-prefs.h"
+#include "ephy-profile-migration.h"
 #include "ephy-debug.h"
+#include "eggsmclient.h"
 
 #include <libxml/xmlversion.h>
 
@@ -42,14 +43,13 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
-#include <libgnome/gnome-program.h>
-#include <libgnomeui/gnome-ui-init.h>
-
-#include <libgnomeui/gnome-app-helper.h>
-
 #include <errno.h>
 #include <string.h>
 
+#ifdef ENABLE_INTROSPECTION
+#include <girepository.h>
+#endif
+
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
 #endif
@@ -72,6 +72,18 @@ static gboolean private_instance = FALSE;
 static gboolean keep_temp_directory = FALSE;
 static char *profile_directory = NULL;
 
+static gboolean
+option_version_cb (const gchar *option_name,
+                   const gchar *value,
+                   gpointer     data,
+                   GError     **error)
+{
+  g_print ("%s %s\n", _("GNOME Web Browser"), VERSION);
+
+  exit (EXIT_SUCCESS);
+ return FALSE;
+}
+ 
 static const GOptionEntry option_entries[] =
 {
 	{ "new-tab", 'n', 0, G_OPTION_ARG_NONE, &open_in_new_tab,
@@ -92,6 +104,8 @@ static const GOptionEntry option_entries[] =
 	  N_("Profile directory to use in the private instance"), N_("DIR") },
 	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &arguments,
 	  "", N_("URL …")},
+	{ "version", 0, G_OPTION_FLAG_NO_ARG | G_OPTION_FLAG_HIDDEN, 
+	  G_OPTION_ARG_CALLBACK, option_version_cb, NULL, NULL },
 	{ NULL }
 };
 
@@ -103,7 +117,7 @@ static GOptionEntry debug_option_entries[] =
 	{ NULL }
 };
 #endif /* GNOME_ENABLE_DEBUG */
-
+ 
 /* adapted from gtk+/gdk/x11/gdkdisplay-x11.c */
 static guint32
 get_startup_id (void)
@@ -417,21 +431,52 @@ show_error_message (GError **error)
 	gtk_dialog_run (GTK_DIALOG (dialog));
 }
 
+static gchar *
+get_accels_filename (void)
+{
+        const char *home;
+
+        home = g_get_home_dir();
+        if (!home)
+                return NULL;
+        return g_build_filename (home, GNOME_DOT_GNOME, "accels", PACKAGE, NULL);
+}
+
+static void
+load_accels (void)
+{
+        char *filename;
+
+        filename = get_accels_filename ();
+        if (!filename)
+                return;
+
+        gtk_accel_map_load (filename);
+        g_free (filename);
+}
+
+static void
+save_accels (void)
+{
+        char *filename;
+
+        filename = get_accels_filename ();
+        if (!filename)
+                return;
+
+        gtk_accel_map_save (filename);
+        g_free (filename);
+}
+
 int
 main (int argc,
       char *argv[])
 {
-	GnomeProgram *program;
 	GOptionContext *option_context;
 	GOptionGroup *option_group;
 	DBusGProxy *proxy;
 	GError *error = NULL;
 	guint32 user_time;
-	const char *env;
-	gboolean enable_pango;
-#ifndef GNOME_PARAM_GOPTION_CONTEXT
-	GPtrArray *fake_argv_array;
-#endif
 
 #ifdef ENABLE_NLS
 	/* Initialize the i18n stuff */
@@ -524,6 +569,13 @@ main (int argc,
 
 	g_option_context_set_main_group (option_context, option_group);
 
+#ifdef ENABLE_INTROSPECTION
+	g_option_context_add_group (option_context, g_irepository_get_option_group ());
+#endif
+
+        g_option_context_add_group (option_context, gtk_get_option_group (TRUE));
+        g_option_context_add_group (option_context, egg_sm_client_get_option_group ());
+
 #ifdef GNOME_ENABLE_DEBUG
 	option_group = g_option_group_new ("debug",
 					   "Epiphany debug options",
@@ -533,17 +585,15 @@ main (int argc,
 	g_option_context_add_group (option_context, option_group);
 #endif /* GNOME_ENABLE_DEBUG */
 
-	program = gnome_program_init (PACKAGE, VERSION,
-				      LIBGNOMEUI_MODULE, argc, argv,
-				      GNOME_PARAM_GOPTION_CONTEXT, option_context,
-				      GNOME_PARAM_HUMAN_READABLE_NAME, _("Web Browser"),
-				      GNOME_PARAM_APP_DATADIR, DATADIR,
-				      NULL);
-
-	/* libgnome keeps a reference to the global program, so drop
-	 * our reference here, to simplify cleanup on the many exit paths.
-	 */
-	g_object_unref (program);
+        if (!g_option_context_parse (option_context, &argc, &argv, &error))
+        {
+                g_print ("Failed to parse arguments: %s\n", error->message);
+                g_error_free (error);
+                g_option_context_free (option_context);
+                exit (1);
+        }
+        
+        g_option_context_free (option_context);
 
 	/* Some argument sanity checks*/
 	if (arguments != NULL && (session_filename != NULL || open_as_bookmarks_editor))
@@ -557,11 +607,6 @@ main (int argc,
 		g_print ("--profile can only be used in combination with --private-instance\n");
 		exit (1);
 	}
-	if (profile_directory != NULL && !g_path_is_absolute (profile_directory))
-	{
-		g_printerr ("The profile directory must be specified with an absolute path.\n");
-		exit (1);
-	}
 
 	if (arguments != NULL &&
 	    eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_ARBITRARY_URL))
@@ -693,7 +738,6 @@ main (int argc,
 	}
 
 	/* We're not remoting; start our services */
-
 	if (!ephy_file_helpers_init (profile_directory,
 				     private_instance,
 				     keep_temp_directory || profile_directory,
@@ -706,29 +750,18 @@ main (int argc,
 		exit (1);
 	}
 
+	/* Migrate profile if we are not running a private instance */
+        if (ephy_has_private_profile () == FALSE)
+          _ephy_profile_migrate ();
+
 	eel_gconf_monitor_add ("/apps/epiphany/general");
 	ephy_stock_icons_init ();
+	load_accels ();
 
 	/* Extensions may want these, so don't initialize in window-cmds */
 	gtk_about_dialog_set_url_hook (handle_url, NULL, NULL);
 	gtk_about_dialog_set_email_hook (handle_email, NULL, NULL);
 
-	/* Work around bug #328844, and avoid the gecko+pango performance problem */
-	env = g_getenv ("MOZ_ENABLE_PANGO");
-	enable_pango = env != NULL &&
-		       env[0] != '\0' &&
-		       g_ascii_strtoull (env, NULL, 10) != 0;
-
-	if (eel_gconf_get_boolean (CONF_GECKO_ENABLE_PANGO))
-	{
-		g_print ("NOTE: Enabling gecko pango renderer; this may cause performance degradation.\n"
-			 "You can set " CONF_GECKO_ENABLE_PANGO " to \"false\" to disable it.\n");
-	}
-	else if (!enable_pango)
-	{
-		g_setenv ("MOZ_DISABLE_PANGO", "1", TRUE);
-	}
-
 	/* Work-around Flash Player crash */
 	g_setenv ("XLIB_SKIP_ARGB_VISUALS", "1", FALSE);
 
@@ -754,7 +787,7 @@ main (int argc,
 		notify_uninit ();
 #endif
 	eel_gconf_monitor_remove ("/apps/epiphany/general");
-	gnome_accelerators_sync ();
+	save_accels ();
 	ephy_state_save ();
 	ephy_file_helpers_shutdown ();
 	xmlCleanupParser ();
